@@ -9,7 +9,7 @@
 VideoInfoExtractor::VideoInfoExtractor(QObject *parent)
     : QObject(parent)
 {
-    connect(this, &VideoInfoExtractor::videoIdChanged, this, [=] {
+    connect(this, &VideoInfoExtractor::videoIdChanged, this, [this] {
         if (m_videoId.isEmpty()) {
             m_videoInfo = {};
             Q_EMIT audioUrlChanged();
@@ -23,7 +23,7 @@ VideoInfoExtractor::VideoInfoExtractor(QObject *parent)
         YTMusicThread::instance()->extractVideoInfo(QString::fromStdString(m_videoId.toStdString()));
     });
 
-    connect(&YTMusicThread::instance().get(), &AsyncYTMusic::extractVideoInfoFinished, this, [=](const video_info::VideoInfo &info) {
+    connect(&YTMusicThread::instance().get(), &AsyncYTMusic::extractVideoInfoFinished, this, [this](const video_info::VideoInfo &info) {
         m_videoInfo = info;
         setLoading(false);
         Q_EMIT audioUrlChanged();
@@ -36,7 +36,7 @@ VideoInfoExtractor::VideoInfoExtractor(QObject *parent)
 QUrl VideoInfoExtractor::audioUrl() const
 {
     if (m_videoInfo.formats.empty()) {
-        return QUrl();
+        return {};
     }
 
     std::vector<video_info::Format> audioFormats;
@@ -48,17 +48,13 @@ QUrl VideoInfoExtractor::audioUrl() const
     });
 
     if (audioFormats.empty()) {
-        return QUrl();
+        return {};
     }
 
-
-    struct {
-        bool operator()(const video_info::Format &a, const video_info::Format &b) {
-            return a.quality > b.quality;
-        }
-    } qualitySort;
-
-    std::sort(audioFormats.begin(), audioFormats.end(), qualitySort);
+    std::sort(audioFormats.begin(), audioFormats.end(),
+              [](const video_info::Format &a, const video_info::Format &b) {
+        return a.quality > b.quality;
+    });
 
     return QUrl(QString::fromStdString(audioFormats.front().url));
 }
